---
name: Bug report
about: Create a report to help us improve
title: "[BUG] - title of the issue"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
for example:
1. use function XXX
2. insert this argument
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. Linux or Windows]
 - em-interpolator version
 - Python version

**Additional context**
Add any other context about the problem here.
